# agen
Utils to generate audio

Depending on what you use, you might need some libraries such as:
```
librosa
soundfile
pyttsx3 (for voiced_time.py)
```

If you get an import error on X, just try to do:
```
pip install X
```
in your terminal.

If that doesn't work, google the library and see how to install it 
For e.g. soundfile is actually obtained by doing
```
pip install pysoundfile
``` 
Buggers!





